================
Upcoming Updates
================

These are the planned updates either being seriously
researched or actively developed upon.

This is also a great place for contributors to get
ideas on how to help with mudicom.

* Basic Anonymization:
    * Groups 0x50XX, 0x60XX, gggg, and eeee still need removed from anonymization process
    * Proper action items on data elements (replace, remove, clean, etc.)
* Detect multiple images within a DICOM file
* Ability to extract multiple images from a DICOM file
* Exception handling for unsupported DICOM files
* Ability to set data element data